@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl,v 1.37.2.84 2005/03/05 19:44:39 jkf Exp $
+#   $Id: ConfigDefs.pl,v 1.37.2.93 2005/08/27 16:03:38 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -81,11 +81,16 @@ deletedvirusmessage		= deletedvirusmessagereport
 deliverdisinfected		= deliverdisinfectedfiles
 deliversilent			= stilldeliversilentviruses
 dirtyheader			= infectedheadervalue
+disarmprependsubject		= disarmedmodifysubject
+disarmsubjecttext		= disarmedsubjecttext
 disinfectedheader		= disinfectedheadervalue
 disinfectedreporttext		= disinfectedreport
 envfromheader			= EnvelopeFromHeader
 envtoheader			= EnvelopeToHeader
 findphishing			= FindPhishingFraud
+gsscanner			= UseCustomSpamScanner
+gstimeout			= CustomSpamScannerTimeout
+gstimeoutlen			= CustomSpamScannertimeouthistory
 hamactions                      = nonspamactions
 hideworkdir			= hideincomingworkdir
 hideworkdirinnotice		= hideincomingworkdirinnotices
@@ -114,6 +119,8 @@ logfacility			= syslogfacility
 maxattachmentsize		= maximumattachmentsize
 maxdirtybytes			= maxunsafebytesperscan
 maxdirtymessages		= maxunsafemessagesperscan
+maxgssize			= maxcustomspamscannersize
+maxgstimeouts			= maxcustomspamscannertimeouts
 maxmessagesize			= maximummessagesize
 maxparts			= maximumattachmentspermessage
 maxunscannedbytes		= maxunscannedbytesperscan
@@ -124,10 +131,13 @@ minstars			= minimumstarsifonspamlist
 nameprependsubject		= filenamemodifysubject
 namesubjecttext			= filenamesubjecttext
 noisyviruses			= nonforgingviruses
+normalrbls                      = spamliststobespam
 nosenderprecedence		= nevernotifysendersofprecedence
 noticefullheaders		= noticesincludefullheaders
 noticerecipient			= noticesto
+phishinghighlight		= highlightphishingfraud
 phishingnumbers			= alsofindnumericphishing
+phishingsubjecttag		= phishingsubjecttext
 phishingwhitelist		= phishingsafesitesfile
 outqueuedir			= outgoingqueuedir
 quarantinesilent		= quarantinesilentviruses
@@ -139,6 +149,7 @@ satimeoutlen			= spamassassintimeoutshistory
 removeheaders			= removetheseheaders
 reqspamassassinscore		= requiredspamassassinscore
 saviwatchfiles                  = monitorsforsophosupdates
+scanmail			= scanmessages
 scoreformat			= spamscorenumberformat
 sendercontentreport		= senderbadcontentreport
 senderfilenamereport		= senderbadfilenamereport
@@ -174,6 +185,7 @@ mcpreqspamassassinscore		= mcprequiredspamassassinscore
 mcpwhitelist			= isdefinitelynotmcp
 unscannedheader			= unscannedheadervalue
 usedefaultswithmanyrecips       = usedefaultruleswithmultiplerecipients
+tagphishingsubject		= phishingmodifysubject
 #virusbeforespammcp		= virusscanningbeforespamormcp
 virusprependsubject		= virusmodifysubject
 virusscan			= virusscanning
@@ -239,10 +251,14 @@ clamavmaxfilesize               10000000
 clamavmaxratio                  250
 CriticalQueueSize		5000
 FileTimeout			30
+GSTimeout			40
+GSTimeoutLen			20
 MaxUnscannedBytes		100000000
 MaxUnscannedMessages		100
 MaxDirtyBytes			50000000
 MaxDirtyMessages		100
+MaxGSSize			20000
+MaxGSTimeouts			10
 MaxSpamAssassinTimeouts		10
 MaxSpamAssassinSize		50000
 QueueScanInterval		5
@@ -320,8 +336,10 @@ DeliverDisinfected	1	no	0	yes	1
 DeliverSilent		1	no	0	yes	1
 deliverunparsabletnef	0	no	0	yes	1
 deliverymethod		batch	batch	batch	queue	queue
+DisarmPrependSubject	1	no	0	yes	1
 EnableSpamBounce	0	no	0	yes	1
 findarchivesbycontent	1	no	0	yes	1
+gsscanner		0	no	0	yes	1
 HideWorkDir		1	no	0	yes	1
 HideWorkDirInNotice	0	no	0	yes	1
 HighMCPPrependSubject	1	no	0	yes	1
@@ -410,6 +428,7 @@ MCPHighSpamAssassinScore	10
 MCPReqSpamAssassinScore		1
 MinAttachmentSize		-1
 MinStars			0
+NormalRBLs			1
 ReqSpamAssassinScore		5
 
 [First,Other]
@@ -418,6 +437,7 @@ AttachmentWarningFilename	VirusWarning.txt
 cleanheader			Found to be clean
 ContentSubjectText		{DANGEROUS?}
 dirtyheader			Found to be infected
+DisarmSubjectText		{Disarmed}
 DisinfectedHeader		Disinfected
 EnvFromHeader			X-MailScanner-Envelope-From:
 EnvToHeader			X-MailScanner-Envelope-To:
@@ -431,6 +451,7 @@ MailHeader			X-MailScanner:
 NameSubjectText			{VIRUS?}
 NoticesFrom			MailScanner
 NoticeSignature			-- \nMailScanner\nEmail Virus Scanner\nwww.mailscanner.info
+PhishingSubjectTag		{Fraud?}
 ScannedSubjectText		{Scanned}
 ScoreFormat			%d
 Sendmail2			/usr/sbin/sendmail
@@ -464,12 +485,16 @@ DangerScan		1	no	0	yes	1
 DeliverCleanedMessages	1	no	0	yes	1
 FindPhishing		0	no	0	yes	1
 markinfectedmessages	1	no	0	yes	1
+PhishingHighlight	1	no	0	yes	1
 HtmlToText		0	no	0	yes	1
 PhishingNumbers		1	no	0	yes	1
 QuarantineInfections	1	no	0	yes	1
+QuarantineModifiedBody	0	no	0	yes	1
 QuarantineSilent	1	no	0	yes	1
 QuarantineWholeMessage	0	no	0	yes	1
+ScanMail		1	no	0	yes	1
 SpamStars		0	no	0	yes	1
+TagPhishingSubject	0	no	0 	yes	1
 MCPUseSpamAssassin	1	no	0	yes	1
 UseSpamAssassin		0	no	0	yes	1
 VirusScan		1	no	0	yes	1
