@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: CustomConfig.pm,v 1.3.2.28 2004/09/25 13:09:32 jkf Exp $
+#   $Id: CustomConfig.pm,v 1.3.2.33 2005/03/16 17:00:56 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ no  strict 'subs'; # Allow bare words for parameter %'s
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.3.2.28 $, 10;
+$VERSION = substr q$Revision: 1.3.2.33 $, 10;
 
 #
 # These are the custom functions that you can write to produce a value
@@ -729,6 +729,16 @@ sub MultipleQueueDir {
 # in MailScanner.conf.
 # You will also need to look at the end of this file for the contents
 # of an hourly cron job to clear out old entries from the database.
+#
+# NOTE: Postfix Users
+# ===================
+# To be able to use IPBlock make sure that you have the
+# smtpd_client_restrictions entry with /etc/postfix/access.
+#
+# Your entry should look some thing like this
+# smtpd_client_restrictions = check_client_access hash:/etc/postfix/access
+#			      ......... other checks for client restrictions			      
+
 
 # Import the flock names
 use Fcntl qw(:DEFAULT :flock);
@@ -740,24 +750,47 @@ use IO;
 BEGIN { @AnyDBM_File::ISA = qw(DB_File GDBM_File NDBM_File SDBM_File) }
 use AnyDBM_File;
 
-
 # You may need to configure these for your site:
 my $WhitelistFile= '/etc/MailScanner/IPBlock.conf';
 my $LockFile     = '/var/spool/MailScanner/IPBlock.lock';
 #my $LogFile     = '/var/spool/MailScanner/IPBlock.log';
 my $BlockDB      = '/var/spool/MailScanner/IPBlock.db';
-my $AccessDB     = '/etc/mail/access.db';
-my $Refusal      = '"550 Site blocked by MailScanner due to excessive email"';
 my $DefaultMaxMessagesPerHour = 1000; # 999999999
+my $FailCode     = '550';
 
 my(%IP2Limit, %IPBWhiteCIDR);
 my(%CIDRtoLimit); # Map CIDR onto limit
 my(@CIDRlist);    # Ordered list of rules, all in CIDR form
 my($hostname);
 
+my $ConfFile = $ARGV[0];
+$ConfFile = $ARGV[1] if $ConfFile =~ /^-+v/i;
+
+my ($AccessDB, $Refusal, $my_mta); # Generalized here for Multiple MTA support
+$my_mta = lc(MailScanner::Config::QuickPeek($ConfFile, 'mta')) if $ConfFile;
+if ($my_mta eq "postfix") { 
+  $AccessDB = "/etc/postfix/access.db";
+  $Refusal = "$FailCode Site blocked by MailScanner due to excessive email";
+
+} elsif ($my_mta eq "sendmail") {
+  $AccessDB = "/etc/mail/access.db";
+  $Refusal = "\"$FailCode Site blocked by MailScanner due to excessive email\"";
+} else {
+  $AccessDB = "";
+  $Refusal = "";
+}
+
+
 sub InitIPBlock {
   my($LimitsH, $cidr, $limit, $counter);
 
+  # Skip IP block initialization if not postfix or sendmail
+  if ($my_mta !~ /postfix|sendmail/) {
+    MailScanner::Log::ErrorLog("IPBlock Currently not supported " .
+                               "for your MTA %s", $my_mta);
+    return 1;
+  }
+
   MailScanner::Log::InfoLog("Initialising IP blocking");
   my $LimitsH = new FileHandle;
   unless ($LimitsH->open($WhitelistFile)) {
@@ -827,6 +860,14 @@ sub EndIPBlock {
 sub IPBlock {
   my($message) = @_;
 
+  # Skip IPblock if not sendmail or postfix
+
+  if ($my_mta !~ /postfix|sendmail/) {
+    MailScanner::Log::ErrorLog("IPBlock Currently not supported for " .
+                               "your MTA %s", $my_mta);
+    return 1;
+  }
+
   return 1 unless $message; # Default if no message passed in
 
   my $ip = $message->{clientip};
@@ -1633,23 +1674,50 @@ __DATA__
 #      SO17 1BJ
 #      United Kingdom
 #
-
+push @INC,"/usr/lib/MailScanner","/opt/MailScanner/lib";
 use FileHandle;
 use Fcntl qw(:DEFAULT :flock);
 use Sys::Syslog;
 BEGIN { @AnyDBM_File::ISA = qw(DB_File GDBM_File NDBM_File SDBM_File) }
 use AnyDBM_File;
-
+require MailScanner::Config;
 use strict 'vars';
 use strict 'refs';
 no  strict 'subs'; # Allow bare words for parameter %'s
 
+my $FailCode = '550';
+
+my $ConfFile = $ARGV[0];
+die "Usage : <scriptname> /path/to/MailScanner.conf\n" if($ConfFile eq "");
+
+my ($AccessDB, $Refusal, $my_mta); # Generalized here for Multiple MTA support
+$my_mta = lc(MailScanner::Config::QuickPeek($ConfFile, 'mta'));
+if( $my_mta eq "postfix" ) {
+
+	$AccessDB = "/etc/postfix/access.db";
+	$Refusal = "$FailCode Site blocked by MailScanner due to excessive email";
+
+}elsif( $my_mta eq "sendmail"){
+
+	$AccessDB = "/etc/mail/access.db";
+	$Refusal = "\"$FailCode Site blocked by MailScanner due to excessive email\"";
+
+}else{
+# Set some values for these variables	
+	$AccessDB = "";
+	$Refusal = "";
+	print STDERR "IPBlock is currently not supported for your MTA\n";
+	exit 0; # No need to do further processing if I don't know the MTA
+}
+
+
+
 my $OneHour      = 3600; # seconds
 my $LockFile     = '/var/spool/MailScanner/IPBlock.lock';
 #my $LogFile     = '/var/spool/MailScanner/IPBlock.log';
 my $BlockDB      = '/var/spool/MailScanner/IPBlock.db';
-my $AccessDB     = '/etc/mail/access.db';
-my $Refusal      = '"550 Site blocked by MailScanner due to excessive email"';
+#my $AccessDB     = '/etc/mail/access.db';
+#my $Refusal      = '"451 Site blocked by MailScanner due to excessive email"';
 
 # Start logging
 Sys::Syslog::openlog("IPBlock", 'pid, nowait', 'mail');
@@ -1749,7 +1817,8 @@ sub BailOut {
   exit 1;
 }
 
-# ---SNIP---
+#---SNIP---
+
 #
 #
 # This is the end of the IPBlock cron job
