@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MCPMessage.pm,v 1.1.2.22 2005/04/29 21:23:24 jkf Exp $
+#   $Id: MCPMessage.pm,v 1.1.2.28 2005/09/15 09:29:27 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ install MIME::Decoder::UU 'uuencode';
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.22 $, 10;
+$VERSION = substr q$Revision: 1.1.2.28 $, 10;
 
 # Is this message spam? Try to build the spam report and store it in
 # the message.
@@ -291,6 +291,14 @@ sub HandleMCP {
   #print STDERR "Message: HandleHamSpam has actions " . join(',',@actions) .
   #             "\n";
 
+  # If they have just specified a filename, then something is wrong
+  if ($#actions==0 && $actions[0] =~ /\//) {
+    MailScanner::Log::WarnLog('Your MCP actions "%s" looks like a filename.' .
+        ' If this is a ruleset filename, it must end in .rule or .rules',
+        $actions[0]);
+    $actions[0] = 'deliver';
+  }
+
   foreach $action (@actions) {
     $actions{$action} = 1;
     #print STDERR "Message: HandleSpam action is $action\n";
@@ -314,13 +322,13 @@ sub HandleMCP {
     # Message is going to original recipient and/or extra recipients
     #
 
-    # Delete action is over-ridden as we are sending it somewhere
-    delete $actions{'delete'};
-
     MailScanner::Log::InfoLog("MCP Actions: message %s actions are %s",
                               $this->{id}, join(',', keys %actions))
       if $HamSpam eq 'mcp' && MailScanner::Config::Value('logmcp');
 
+    # Delete action is over-ridden as we are sending it somewhere
+    delete $actions{'delete'};
+
     # Delete the original recipient if they are only forwarding it
     $this->{mcpdelivering} = 1;
     if (!$actions{'deliver'}) {
@@ -335,7 +343,7 @@ sub HandleMCP {
 
     MailScanner::Log::InfoLog("MCP Actions: message %s actions are %s",
                               $this->{id}, join(',', keys %actions))
-      if $HamSpam eq 'spam' && MailScanner::Config::Value('logmcp');
+      if $HamSpam eq 'mcp' && MailScanner::Config::Value('logmcp');
 
     # Mark the message as deleted, so it won't get delivered
     #$this->{deleted} = 1;
@@ -645,6 +653,7 @@ sub HandleMCPNotify {
 
   # Send the message to the spam sender, but ensure the envelope
   # sender address is "<>" so that it can't be bounced.
+  #print STDERR "Sending notify:\n$emailmsg\nEnd notify.\n";
   $global::MS->{mta}->SendMessageString($this, $emailmsg, $localpostmaster)
     or MailScanner::Log::WarnLog("Could not send recipient mcp notify, %s", $!);
 }
