@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm,v 1.64.2.31 2005/04/01 16:34:20 jkf Exp $
+#   $Id: MessageBatch.pm,v 1.64.2.37 2005/08/28 15:08:49 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,10 +41,11 @@ no  strict 'subs'; # Allow bare words for parameter %'s
 
 use DirHandle;
 
+
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.64.2.31 $, 10;
+$VERSION = substr q$Revision: 1.64.2.37 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -192,6 +193,12 @@ sub RemoveDeletedMessages {
 
   my($id, $message, @badentries);
 
+  my $deleteifnotdelivering = 0;
+  $deleteifnotdelivering = 1
+    if MailScanner::Config::IsSimpleValue('keepspamarchiveclean') &&
+       !MailScanner::Config::Value('keepspamarchiveclean');
+  #print STDERR "Deleteifnotdelivering = $deleteifnotdelivering\n";
+
   #print STDERR "About to remove deleted messages\n";
   while(($id, $message) = each %{$this->{messages}}) {
     #print STDERR "Looking at $id for deletion\n";
@@ -202,7 +209,9 @@ sub RemoveDeletedMessages {
     }
     #MailScanner::Log::InfoLog("RemoveDeletedMessages: Deleting message $id")
     #  if $message->{deleted};
-    $message->DeleteMessage() if $message->{deleted};
+    #print STDERR "Message->deleted = " . $message->{deleted} . "and dontdeliver = " . $message->{dontdeliver} . "\n";
+    $message->DeleteMessage() if $message->{deleted} ||
+      ($message->{dontdeliver} && $deleteifnotdelivering);
     #delete $this->{messages}{$id} if $this->{messages}{$id}->{deleted};
   }
   foreach $id (@badentries) {
@@ -225,6 +234,7 @@ sub SpamChecks {
     if MailScanner::Config::Value('logspam');
 
   while(($id, $message) = each %{$this->{messages}}) {
+    next unless $message->{scanmail};
     next if $message->{deleted};
     next unless MailScanner::Config::Value('spamchecks', $message) =~ /1/;
  
@@ -235,7 +245,6 @@ sub SpamChecks {
       $message->{spamreport} = MailScanner::Config::LanguageValue($message,
                                ($message->{isspam}?'spam':'notspam'));
     }
-    #print STDERR "Spam header = \"" . $message->{spamreport} . "\"\n";
   }
   MailScanner::Log::InfoLog("Spam Checks: Found $counter spam messages")
     if $counter>0;
@@ -256,6 +265,7 @@ sub HandleSpam {
     # Skip deleted and non-spam messages
     next if  $message->{deleted} ||
             !$message->{isspam}  ||
+            !$message->{scanmail}||
              $message->{spamwhitelisted};
 
     #print STDERR "Spam checks for $id\n";
@@ -277,6 +287,7 @@ sub HandleHam {
   while(($id, $message) = each %{$this->{messages}}) {
     # Skip deleted and non-spam messages
     next if $message->{deleted} ||
+           !$message->{scanmail}||
             $message->{isspam};
 
     #print STDERR "Ham checks for $id\n";
@@ -301,6 +312,7 @@ sub MCPChecks {
 
   while(($id, $message) = each %{$this->{messages}}) {
     next if $message->{deleted};
+    next unless $message->{scanmail};
     next unless MailScanner::Config::Value('mcpchecks', $message);
  
     #print STDERR "Spam checks for $id\n";
@@ -330,7 +342,8 @@ sub HandleMCP {
   while(($id, $message) = each %{$this->{messages}}) {
     # Skip deleted and non-spam messages
     next if  $message->{deleted} ||
-            !$message->{ismcp}  ||
+            !$message->{ismcp}   ||
+            !$message->{scanmail}||
              $message->{mcpwhitelisted};
 
     #print STDERR "Spam checks for $id\n";
@@ -352,6 +365,7 @@ sub HandleNonMCP {
   while(($id, $message) = each %{$this->{messages}}) {
     # Skip deleted and non-spam messages
     next if $message->{deleted} ||
+           !$message->{scanmail}||
             $message->{ismcp};
 
     #print STDERR "Ham checks for $id\n";
@@ -373,6 +387,15 @@ sub DeliverUnscanned {
   while(($id,$message) = each %{$this->{messages}}) {
     next if $message->{deleted} || $message->{dontdeliver};
 
+    # This is for mail we don't want to touch at all
+    if (!$message->{scanmail}) {
+      $OutQ = MailScanner::Config::Value('outqueuedir', $message);
+      $message->DeliverUntouched($OutQ);
+      $message->{deleted} = 1; # This marks it for purging from disk
+      push @messages, $message;
+      next;
+    }
+
     if (!$message->{scanme}) {
       #print STDERR "Delivering unscanned message $id\n";
 
@@ -502,7 +525,8 @@ sub RemoveInfectedSpam {
     next unless
       MailScanner::Config::Value('keepspamarchiveclean', $message) =~ /1/;
     #print STDERR "Deleting " . join(',',@{$message->{spamarchive}}) . "\n";
-    unlink @{$message->{spamarchive}};
+    unlink @{$message->{spamarchive}}; # Wipe the spamarchive files
+    @{$this->{spamarchive}} = (); # Wipe the spamarchive array
   }
 }
 
@@ -615,9 +639,27 @@ sub QuarantineInfections {
                 =~ /1/;
     #print STDERR "Quarantining infections for $id\n";
     $global::MS->{quar}->StoreInfections($message);
+    $message->{quarantinedinfections} = 1; # Stop it quarantining it twice
   }
 }
 
+# Store all the disarmed files in the quarantine if they want me to.
+# Quarantine decision has to be done on a per-message basis.
+sub QuarantineModifiedBody {
+  my $this = shift;
+
+  my($id, $message);
+
+  while(($id, $message) = each %{$this->{messages}}) {
+    next unless $message->{bodymodified};
+    next if $message->{quarantinedinfections}; # Optimisation
+    next if MailScanner::Config::Value ('quarantinemodifiedbody', $message) !~
+            /1/;
+
+    $global::MS->{quar}->StoreInfections($message);
+    MailScanner::Log::InfoLog("Quarantining modified message for %s", $id);
+  }
+}
 
 # Sign all the messages that were clean with a tag line saying
 # (ideally) that MailScanner is wonderful :-)
