@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: PFDiskStore.pm,v 1.1.2.35 2005/03/31 19:57:31 jkf Exp $
+#   $Id: PFDiskStore.pm,v 1.1.2.37 2005/07/05 14:14:51 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.35 $, 10;
+$VERSION = substr q$Revision: 1.1.2.37 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -59,7 +59,7 @@ $VERSION = substr q$Revision: 1.1.2.35 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 1.1.2.35 $, 10;
+#$VERSION = substr q$Revision: 1.1.2.37 $, 10;
 
 # Attributes are
 #
@@ -210,20 +210,37 @@ sub WriteHeader {
   my $this = shift;
   my($message, $Outq) = @_;
 
-  my($tfile, $Tf, $predata, $HeaderStartPos);
+  my($tfile, $Tf, $predata, $HeaderStartPos, $TimestampInPre);
 
   #print STDERR "Writing header for message " . $message->{id} . "\n";
   $tfile = $Outq . '/' . $this->{tname};
   #$file  .= '/' . $this->{tname};
   #print STDERR "Writing header to temp file $tfile\n";
 
+  ($predata, $HeaderStartPos, $TimestampInPre)
+    = MailScanner::Sendmail::PreDataString($message);
+
+  # If we found more than 1 timestamp in the pre-data string, then
+  # ditch this message and leave it back in the incoming queue
+  #print STDERR "Predata is \"$predata\"\n";
+  #print STDERR "HeaderStartPos is \"$HeaderStartPos\"\n";
+  #print STDERR "TimestampInPre is \"$TimestampInPre\"\n";
+  if ($TimestampInPre != 1) {
+    # Quietly drop the data structures of this message.
+    MailScanner::Log::WarnLog("Message %s is currently invalid, retrying",
+                              $message->{id});
+    my @toclear = ( $message->{id} );
+    $global::MS->{work}->ClearIds(\@toclear); # Delete attachments
+    $message->DropFromBatch();
+    return;
+  }
+
   umask 0077; # Add this to try to stop 0666 qf files
   $Tf = new FileHandle;
   MailScanner::Lock::openlock($Tf, "+>$tfile", "w")
     or MailScanner::Log::DieLog("Cannot create + lock clean tempfile %s, %s",
                                 $tfile, $!);
 
-  ($predata, $HeaderStartPos) = MailScanner::Sendmail::PreDataString($message);
   #print STDERR "Writing predata \"$predata\"\n";
   #print STDERR "Length of predata is " . length($predata) . "\n";
   #print STDERR "Before writing predata we are at " . $Tf->tell . "\n";
@@ -290,14 +307,30 @@ sub WriteHeader {
       exit;
     }
   }
-  my($PostStartPos, $HeaderLength);
+  my($PostStartPos, $HeaderLength, $PostData, $TimestampInPost);
   $PostStartPos = tell $Tf;
   #print STDERR "\n\nPost data starts at $PostStartPos\n";
 
-  $Tf->print(MailScanner::Sendmail::PostDataString($message));
-  #print STDERR "PostDataString = \"" . MailScanner::Sendmail::PostDataString($message) . "\"\n";
+  ($PostData, $TimestampInPost)
+    = MailScanner::Sendmail::PostDataString($message);
+  $Tf->print($PostData);
+  #print STDERR "TimestampInPost = \"$TimestampInPost\"\n";
+  #print STDERR "PostDataString = \"$PostData\"\n";
   $Tf->flush();
 
+  # If we found any timestamp in the post-data string, and we had one in
+  # the pre-data string, then ditch this message and leave it back in the
+  # incoming queue.
+  if ($TimestampInPre && $TimestampInPost) {
+    #print STDERR "We had trouble!\n";
+    # Quietly drop the data structures of this message.
+    $message->{deleted} = 1;
+    $message->{gonefromdisk} = 1; # Don't try to delete the original
+    unlink $tfile; # Delete the new file from the queue
+    MailScanner::Lock::unlockclose($Tf);
+    return;
+  }
+
   # Now over-write the length records in the 1st record and in the M record
   seek $Tf, 2, 0;
 
