@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Postfix.pm,v 1.1.2.61 2005/03/31 19:57:31 jkf Exp $
+#   $Id: Postfix.pm,v 1.1.2.64 2005/07/31 16:28:18 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.61 $, 10;
+$VERSION = substr q$Revision: 1.1.2.64 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -285,12 +285,13 @@ sub new {
     my($ip, $TOline);
     my($Line, $Flags);
     my($MsgContSize, $DataOffset, $NumRecips);
-    my($TOFound, $FROMFound, $IPFound);
-    my($rectype, $recdata);
+    my($TOFound, $FROMFound, $IPFound, $TIMEFound);
+    my($ErrorFound, $ERecordFound, $rectype, $recdata);
 
     #print STDERR "In ReadQf\n";
     #$message->{store}->print();
     $message->{nobody} = 0; # If there is no message body we just get X at end of headers
+    $ERecordFound = 0;
 
     # Just in case we get a message with no headers at all
     @{$message->{headers}} = ();
@@ -325,6 +326,13 @@ sub new {
     #print STDERR "Data offset  = $DataOffset\n";
     #print STDERR "Num Recips   = $NumRecips\n";
 
+    # If the data offset is 0 then Postfix definitely hasn't finished
+    # writing the message.
+    unless ($DataOffset+0 > 10) { # 10 == arbitrary small number
+      $message->DropFromBatch();
+      return 0;
+    }
+
     # Read records until we hit the start of the message M record
     #print STDERR "Reading pre data\n";
     while(($rectype, $recdata) = ReadRecord($RQf)) {
@@ -417,8 +425,17 @@ sub new {
       #print STDERR "Metadata type $rectype data \"$recdata\"\n";
       if ($rectype eq 'E') {
         push @{$message->{metadata}}, "$rectype$recdata";
+        $ERecordFound = 1;
         last;
       }
+      # JKF 20050621 Must only ever find 1 timestamp or the message is corrupt
+      if ($rectype eq 'T') {
+        if ($TIMEFound) {
+          $ErrorFound = 1;
+          last;
+        }
+        $TIMEFound = 1;
+      }
       #JKF 20040322 if ($rectype eq 'R') {
       if ($rectype eq 'O') {
         # Recipient address
@@ -476,7 +493,16 @@ sub new {
     # Decode the ISO encoded Subject line
     $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
 
-    return 1 if $FROMFound && $TOFound; # && $IPFound;
+    # If we never found the E (end of message file) record, then
+    # Postfix is definitely still writing the message.
+    unless ($ERecordFound) {
+      MailScanner::Log::WarnLog("No end-of-message record found in %s, " .
+                                "retrying", $message->{id});
+      $message->DropFromBatch();
+      return 0;
+    }
+
+    return 1 if $FROMFound && $TOFound && !$ErrorFound; # && $IPFound;
     #MailScanner::Log::WarnLog("Batch: Found invalid queue file for " .
     #                          "message %s", $message->{id});
     return 0;
@@ -879,6 +905,7 @@ sub new {
     my($message) = @_;
 
     my($linenum, $result, $type, $data, $to, $preNlen);
+    my $TimestampFound = 0;
 
     #print STDERR "In PreDataString\n";
     # Output all the metadata records up until (& including) the M record.
@@ -887,6 +914,7 @@ sub new {
     foreach (@{$message->{metadata}}) {
       /^(.)(.*)$/;
       ($type, $data) = ($1, $2);
+      $TimestampFound++ if $type eq 'T'; # Must only ever have 1 timestamp
       #print STDERR "PreData1 Type $type Data $data\n";
       last if $type eq 'M';
       $result .= Record2String($type, $data);
@@ -938,7 +966,7 @@ sub new {
 
     #print STDERR "Result of PreDataString is $result\n";
     # Return the string and the length of the data before any N records
-    return ($result, $preNlen);
+    return ($result, $preNlen, $TimestampFound);
   }
 
   sub PostDataString {
@@ -947,6 +975,7 @@ sub new {
 
     my($result, $type, $data);
     my($record, $recordnum);
+    my $TimestampFound = 0;
     $result = Record2String('X', "");
 
     $recordnum = @{$message->{metadata}} - 1;
@@ -956,10 +985,11 @@ sub new {
       $record =~ /^(.)(.*)$/;
       ($type, $data) = ($1, $2);
       $result .= Record2String($type, $data);
+      $TimestampFound++ if $type eq 'T';
       #print STDERR "Post $type $data\n";
     }
 
-    return $result;
+    return($result, $TimestampFound);
   }
 
 
@@ -1084,7 +1114,7 @@ sub FindHashDirDepth {
     while(defined($dir1name = $here->read())) {
       #MailScanner::Log::WarnLog("JKF: Reading %s from dir .", $dir1name);
       next if $dir1name eq '.' || $dir1name eq '..';
-      $filecount++ if -f $dir1name;
+      $filecount++ if -f $dir1name && $dir1name =~ /$mta->{HDFileRegexp}/;
       next unless -d $dir1name;
       $dir1->open($dir1name)
         or MailScanner::Log::DieLog("Cannot open dir %s when finding depth",
