@@ -5,7 +5,7 @@
 #   OpenProtect - Server Side E-Mail Protection	
 #   Copyright (C) 2003 Opencomputing Technologies
 #
-#   $Id: Qmail.pm,v 1.1.2.6 2004/12/18 12:25:46 jkf Exp $
+#   $Id: Qmail.pm,v 1.1.2.9 2005/03/27 18:21:32 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.6 $, 10;
+$VERSION = substr q$Revision: 1.1.2.9 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -270,6 +270,9 @@ sub new {
     }
     return 1 if $TOFound;
     
+    # Decode the ISO encoded Subject line
+    $message->{subject} = MIME::WordDecoder::unmime($message->{subject});
+
     $message->{store}->DeleteUnlock();
     
     #KMG: three cheers to christophe @ digital network for his persistence and resourcefulness :)    
@@ -307,6 +310,22 @@ sub new {
     }
   }
 
+  # Delete all duplicates of a header.
+  sub UniqHeader {
+    my($this, $message, $key) = @_;
+    my($linenum, $foundat);
+    $foundat = -1;
+    for($linenum=0; $linenum<@{$message->{wheaders}}; $linenum++) {
+    	next unless $message->{wheaders}[$linenum] =~ /^$key/i;
+        ($foundat = $linenum), next if $foundat == -1;
+	splice(@{$message->{wheaders}}, $linenum, 1);
+	while($message->{wheaders}[$linenum] =~ /^\s/) {
+		splice(@{$message->{wheaders}}, $linenum, 1);
+	}
+	$linenum--;
+    }
+  }
+
   sub ReplaceHeader {
     my($this, $message, $key, $newvalue) = @_;
 
@@ -761,7 +780,8 @@ sub new {
         #print STDERR "Qmail.pm: Added $id to batch\n";
         $batchempty = 0;
 
-        if (MailScanner::Config::Value("virusscan", $newmessage)) {
+        if (MailScanner::Config::Value("virusscan", $newmessage) ||
+            MailScanner::Config::Value("dangerscan", $newmessage)) {
           $newmessage->NeedsScanning(1);
           $DirtyMsgs++;
           $DirtyBytes += $newmessage->{size};
