@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Quarantine.pm,v 1.11.2.6 2005/03/20 13:38:19 jkf Exp $
+#   $Id: Quarantine.pm,v 1.11.2.7 2005/09/15 09:29:28 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ use File::Copy;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.11.2.6 $, 10;
+$VERSION = substr q$Revision: 1.11.2.7 $, 10;
 
 # Attributes are
 #
@@ -71,6 +71,11 @@ sub new {
     $destgid = $destgname?getgrnam($destgname):0;
     $this->{gid} = $destgid if $destgid != $currentgid;
     $this->{uid} = $destuid if $destuid != $currentuid;
+  } else {
+    $destuid = 0;
+    $destgid = 0;
+    $this->{gid} = 0;
+    $this->{uid} = 0;
   }
 
   # Create a test file to try with chown
