@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SA.pm,v 1.35.2.49 2005/03/12 20:15:19 jkf Exp $
+#   $Id: SA.pm,v 1.35.2.53 2005/09/15 10:27:50 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ use POSIX qw(:signal_h); # For Solaris 9 SIG bug workaround
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.35.2.49 $, 10;
+$VERSION = substr q$Revision: 1.35.2.53 $, 10;
 
 # Attributes are
 #
@@ -229,6 +229,9 @@ sub initialise {
     # Apparently this doesn't do anything after compile_now()
     #$MailScanner::SA::SAspamtest->read_scoreonly_config($prefs);
   }
+
+  # Turn off warnings again, as SpamAssassin switches them on
+  $^W = 0;
 }
 
 
@@ -247,7 +250,8 @@ sub Checks {
 
   my($dfhandle);
   my($dfilename, $dfile, @WholeMessage, $SAResult, $SAHitList);
-  my($HighScoring, $SAScore, $maxsize, $SAReport);
+  my($HighScoring, $SAScore, $maxsize, $SAReport, $GSHits);
+  $GSHits = $message->{gshits} || 0.0;
 
   # Bail out and fake a miss if too many consecutive SA checks failed
   my $maxfailures = MailScanner::Config::Value('maxspamassassintimeouts');
@@ -399,12 +403,14 @@ sub Checks {
   # Test it for spam-ness
   if ($SAversion<3) {
     ($SAResult, $HighScoring, $SAHitList, $SAScore, $SAReport) 
-      = SAForkAndTest($MailScanner::SA::SAspamtest, $spammail, $message);
+      = SAForkAndTest($GSHits, $MailScanner::SA::SAspamtest,
+                      $spammail, $message);
   } else {
     #print STDERR "Check 1, report template = \"" .
     #      $MailScanner::SA::SAspamtest->{conf}->{report_template} . "\"\n";
     ($SAResult, $HighScoring, $SAHitList, $SAScore, $SAReport) 
-      = SAForkAndTest($MailScanner::SA::SAspamtest, \@WholeMessage, $message);
+      = SAForkAndTest($GSHits, $MailScanner::SA::SAspamtest,
+                      \@WholeMessage, $message);
   }
 
   #MailScanner::Log::WarnLog("Done SAForkAndTest");
@@ -422,7 +428,7 @@ sub Checks {
 # of the SpamAssassin checks, which occasionally take a *very* long time to
 # terminate due to regular expression backtracking and other nasties.
 sub SAForkAndTest {
-  my($Test, $Mail, $Message) = @_;
+  my($GSHits, $Test, $Mail, $Message) = @_;
 
   my($pipe);
   my($SAHitList, $SAHits, $SAReqHits, $IsItSpam, $IsItHighScore, $AutoLearn);
@@ -641,9 +647,17 @@ sub SAForkAndTest {
   MailScanner::Log::DebugLog("SpamAssassin returned $PipeReturn");
 
   #$PipeReturn = $PipeReturn>>8;
-  $IsItSpam = ($SAHits && $SAHits>=$SAReqHits)?1:0;
+  if ($SAHits && ($SAHits+$GSHits>=$SAReqHits)) {
+    $IsItSpam = 1;
+  } else {
+    $IsItSpam = 0;
+  }
   $HighScoreVal = MailScanner::Config::Value('highspamassassinscore',$Message);
-  $IsItHighScore = ($SAHits && $HighScoreVal>0 && $SAHits>=$HighScoreVal)?1:0;
+  if ($SAHits && $HighScoreVal>0 && ($SAHits+$GSHits>=$HighScoreVal)) {
+    $IsItHighScore = 1;
+  } else {
+    $IsItHighScore = 0;
+  }
   #print STDERR "Check 3, is \"" . $Test->{conf}->{report_template} . "\"\n";
   return ($IsItSpam, $IsItHighScore, $SAHitList, $SAHits, $SAReport);
 }
