@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SMDiskStore.pm,v 1.27.2.16 2005/02/27 20:30:00 jkf Exp $
+#   $Id: SMDiskStore.pm,v 1.27.2.17 2005/06/03 13:37:20 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.27.2.16 $, 10;
+$VERSION = substr q$Revision: 1.27.2.17 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -59,7 +59,7 @@ $VERSION = substr q$Revision: 1.27.2.16 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 1.27.2.16 $, 10;
+#$VERSION = substr q$Revision: 1.27.2.17 $, 10;
 
 # Attributes are
 #
@@ -177,13 +177,13 @@ sub DeleteUnlock {
   # when killed
   @DeletesPending = ($this->{hpath}, $this->{dpath});
 
-  unlink($this->{hpath});
-  #  or MailScanner::Log::WarnLog("Unlinking %s failed: %s",
-  #                               $this->{hpath}, $!);
+  unlink($this->{hpath})
+    or MailScanner::Log::WarnLog("Unlinking %s failed: %s",
+                                 $this->{hpath}, $!);
   MailScanner::Lock::unlockclose($this->{inhhandle});
-  unlink($this->{dpath});
-  #  or MailScanner::Log::WarnLog("Unlinking %s failed: %s",
-  #                               $this->{dpath}, $!);
+  unlink($this->{dpath})
+    or MailScanner::Log::WarnLog("Unlinking %s failed: %s",
+                                 $this->{dpath}, $!);
   MailScanner::Lock::unlockclose($this->{indhandle});
 
   # Clear list of pending deletes
