@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SweepContent.pm,v 1.17.2.23 2005/02/23 13:30:24 jkf Exp $
+#   $Id: SweepContent.pm,v 1.17.2.24 2005/05/04 15:56:34 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.17.2.23 $, 10;
+$VERSION = substr q$Revision: 1.17.2.24 $, 10;
 
 # Attributes are
 #
@@ -272,7 +272,7 @@ sub CheckAttachmentSizes {
   my($message, $id) = @_;
 
   my($BaseDir, $basefh, $safename, $maxsize, $attachsize, $tnefname);
-  my($unsafename, $counter, $minsize);
+  my($unsafename, $counter, $minsize, $attachentity);
 
   # Read the configuration setting, value<=0 implies setting not in use.
   $maxsize = MailScanner::Config::Value('maxattachmentsize', $message);
@@ -294,11 +294,15 @@ sub CheckAttachmentSizes {
 
     # "Safe" attachment filename is in $safename, this is what we stat
     $attachsize = -s "$BaseDir/$safename";
+    $unsafename = $message->{safefile2file}{$safename} || $tnefname;
+    $attachentity = $message->{file2entity}{$unsafename};
+    next unless $attachentity; # Only check attachment, not contents of zips
+    next if $safename =~ /^msg[-\d]+\.(txt|html)$/;
     #print STDERR "\nSafename = $safename\n";
     #print STDERR "Attachsize=$attachsize\nMin=$minsize\nMax=$maxsize\n";
-    if ($maxsize>=0 && $attachsize > $maxsize &&
-        $safename !~ /^msg[-\d]+\.(txt|html)$/) {
-      $unsafename = $message->{safefile2file}{$safename} || $tnefname;
+    if ($maxsize>=0 && $attachsize > $maxsize) {
+      #print STDERR "$safename is too big $attachsize > $maxsize\n";
+      #print STDERR "Unsafename is $unsafename\n";
       MailScanner::Log::InfoLog("Attachment size check: %s > %s (%s) in %s",
                                 $attachsize, $maxsize, $unsafename, $id);
       $message->{otherreports}{$safename} .=
@@ -307,10 +311,8 @@ sub CheckAttachmentSizes {
       $counter++;
       $message->{otherinfected}++;
     }
-    if ($minsize>=0 && $attachsize < $minsize &&
-        $safename !~ /^msg[-\d]+\.(txt|html)$/) {
+    if ($minsize>=0 && $attachsize < $minsize) {
       #print STDERR "Attachment is too small\n";
-      $unsafename = $message->{safefile2file}{$safename} || $tnefname;
       MailScanner::Log::InfoLog("Attachment size check: %s < %s (%s) in %s",
                                 $attachsize, $minsize, $unsafename, $id);
       $message->{otherreports}{$safename} .=
