@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SweepViruses.pm,v 1.49.2.102 2005/04/27 07:30:58 jkf Exp $
+#   $Id: SweepViruses.pm,v 1.49.2.113 2005/07/11 15:44:22 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION $ScannerPID);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.49.2.102 $, 10;
+$VERSION = substr q$Revision: 1.49.2.113 $, 10;
 
 # Locking definitions for flock() which is used to lock the Lock file
 my($LOCK_SH) = 1;
@@ -103,7 +103,7 @@ my %Scanners = (
     Name		=> 'Sophos',
     Lock		=> 'SophosBusy.lock',
     # In next line, '-ss' makes it work nice and quietly
-    CommonOptions	=> '-sc -f -all -rec -ss -archive -loopback ' .
+    CommonOptions	=> '-sc -f -all -rec -ss -archive -cab -loopback ' .
                            '--no-follow-symlinks --no-reset-atime -TNEF',
     DisinfectOptions	=> '-di',
     ScanOptions		=> '',
@@ -259,9 +259,9 @@ my %Scanners = (
   "panda"	=> {
     Name		=> 'Panda',
     Lock                => 'PandaBusy.lock',
-    CommonOptions       => '-AEX -CMP -AUT -NSO -ESP',
-    DisinfectOptions    => '-CLV',
-    ScanOptions         => '-HEU',
+    CommonOptions       => '-nsb -heu -eng -aex -nso -aut -cmp',
+    DisinfectOptions    => '-clv',
+    ScanOptions         => '-nor',
     InitParser          => \&InitPandaParser,
     ProcessOutput       => \&ProcessPandaOutput,
     SupportScanning     => $S_SUPPORTED,
@@ -846,6 +846,12 @@ sub TryOneCommercial {
   $VirusLock = MailScanner::Config::Value('lockfiledir') . "/" .
                $rScanner->{"Lock"}; # lock file
   $voptions  = $rScanner->{"CommonOptions"}; # Set common command line options
+
+  # Add the configured value for scanner time outs  to the command line
+  # if the scanner is  Panda
+  $voptions .= " -t:".MailScanner::Config::Value('virusscannertimeout')
+  				if $rScanner->{"Name"} eq 'Panda';
+
   # Add command line options to "scan only", or to disinfect
   $voptions .= " " . $rScanner->{$disinfect?"DisinfectOptions":"ScanOptions"};
   &{$$rScanner{"InitParser"}}(); # Initialise scanner-specific parser
@@ -1202,9 +1208,10 @@ sub InitRavParser {
 }
 
 # Initialise any state variables the ClamAV output parser uses
-my ($clamav_archive);
+my ($clamav_archive, $qmclamav_archive);
 sub InitClamAVParser {
   $clamav_archive = "";
+  $qmclamav_archive = "";
 }
 
 # Initialise any state variables the ClamAV Module output parser uses
@@ -1349,8 +1356,31 @@ sub ProcessSophosSAVIOutput {
   ($keyword, $virusname, $filename) = split(/:: /, $line, 3);
 
   if ($keyword =~ /^error/i) {
-    MailScanner::Log::InfoLog("SophosSAVI::%s", $logout);
-    return 1;
+    ($dot, $id, $part, @rest) = split(/\//, $filename);
+    $report = $Name . ': ' if $Name;
+
+    # Allow any error messages that are mentioned in the
+    # Allowed Sophos Error Messages option.
+    my($errorlist, @errorlist, @errorregexps, $choice);
+    $errorlist = MailScanner::Config::Value('sophosallowederrors');
+    $errorlist =~ s/^\"(.+)\"$/$1/; # Remove leading and trailing quotes
+    @errorlist = split(/\"\s*,\s*\"/, $errorlist); # Split up the list
+    foreach $choice (@errorlist) {
+      push @errorregexps, quotemeta($choice) if $choice =~ /[^\s]/;
+    }
+    $errorlist = join('|',@errorregexps); # Turn into 1 big regexp
+
+    if ($errorlist ne "" && $virusname =~ /$errorlist/) {
+      MailScanner::Log::WarnLog("Ignored SophosSAVI '%s' error in %s",
+                                $virusname, $id);
+      return 0;
+    } else {
+      MailScanner::Log::InfoLog("SophosSAVI::%s", $logout);
+      $infections->{"$id"}{"$part"}
+        .= "$report$part caused an error: $virusname\n";
+      $types->{"$id"}{"$part"} .= "v"; # it's a real virus
+      return 1;
+    }
   } elsif ($keyword =~ /^info/i) {
     return 0;
   } elsif ($keyword =~ /^clean/i) {
@@ -1370,7 +1400,7 @@ sub ProcessSophosSAVIOutput {
 
 sub ProcessSophosOutput {
   my($line, $infections, $types, $BaseDir, $Name) = @_;
-  my($report, $infected, $dot, $id, $part, @rest);
+  my($report, $infected, $dot, $id, $part, @rest, $error);
   my($logout);
 
   #print "$line";
@@ -1381,14 +1411,21 @@ sub ProcessSophosOutput {
   MailScanner::Log::InfoLog($logout) if $line =~ /error/i;
   # JKF Improved to handle multi-part split archives,
   # JKF which Sophos whinges about
-  return 0 unless $line =~ /(virus.*found)|(could not check)/i;
+  return 0 unless $line =~ /(virus.*found)|(could not check)|(password[\s-]*protected)/i;
   MailScanner::Log::InfoLog($logout);
   $report = $line;
   $infected = $line;
   $infected =~ s/^.*found\s*in\s*file\s*//i;
   # Catch the extra stuff on the end of the line as well as the start
   $infected =~ s/^Could not check\s*(.+) \(([^)]+)\)$/$1/i;
-  my $error = $2;
+  #print STDERR "Infected = \"$infected\"\n";
+  $error = $2;
+  #print STDERR "Error = \"$error\"\n";
+  if ($error eq "") {
+    $error = "Password protected file"
+      if $infected =~ s/^Password[ -]*protected\s+file\s+(.+)$/$1/i;
+    #print STDERR "Error 2 = \"$error\"\n";
+  }
 
   # If the error is one of the allowed errors, then don't report any
   # infections on this file.
@@ -1402,17 +1439,10 @@ sub ProcessSophosOutput {
     $errorlist =~ s/^\"(.+)\"$/$1/; # Remove leading and trailing quotes
     @errorlist = split(/\"\s*,\s*\"/, $errorlist); # Split up the list
     foreach $choice (@errorlist) {
-      $choice =~ s/[^0-9A-Za-z ]/\\$&/g; # Escape any nasty characters
-      push @errorregexps, $choice; # Add to the list of regexps
+      push @errorregexps, quotemeta($choice) if $choice =~ /[^\s]/;
     }
     $errorlist = join('|',@errorregexps); # Turn into 1 big regexp
 
-    ## Treat their string as a list of words, any of which can match
-    #my $errorlist = MailScanner::Config::Value('sophosallowederrors');
-    #$errorlist =~ s/\s+/ /g;
-    #$errorlist =~ s/[^0-9A-Za-z ]/\\$&/g;
-    #$errorlist =~ s/ /\|/g;
-    ##if ($errorlist ne "" && $errorlist =~ /$error/) {
     if ($errorlist ne "" && $error =~ /$errorlist/) {
       MailScanner::Log::WarnLog("Ignored Sophos '%s' error", $error);
       return 0;
@@ -1882,11 +1912,14 @@ sub ProcessFProtOutput {
   #                 virus infections for easier parsing.
   # JKF 25/02/2002  Add all sorts of patterns gleaned from a coredump of F-Prot
   # JKF 24/07/2002  Reparse the lines to turn them into infection reports
+  # JKF 07/06/2005  Make log output contain the whole path of the file.
   $report = $line;
+  $report =~ s/^.+\/(.+\/.+$)/\.\/$1/; # New
   $logout = $line;
   $logout =~ s/%/%%/g;
   $logout =~ s/\s{20,}/ /g;
   MailScanner::Log::InfoLog($logout);
+  $logout =~ s/^.+\/(.+\/.+$)/\.\/$1/; # New
   if ($line =~ /(is|could be) a (security risk|virus construction)/) {
     $line =~ s/(is|could be) a (security risk|virus construction).*$/Infection: /;
   }
@@ -2130,39 +2163,51 @@ sub ProcessAntiVirOutput {
 # <hector@lared.es>
 # From comment (now removed), it looks to be based on Sophos parser at
 # some point in its history.
+# Updated by Rick Cooper <rcooper@dwford.com> 05/10/2005
 #
 sub ProcessPandaOutput {
   my($line, $infections, $types, $BaseDir, $Name) = @_;
   my($report, $infected, $dot, $id, $part, @rest);
-  my($logout, $numviruses);
+  my($numviruses);
 
+  # Return if there were no viruses found
   return 0 if $line =~ /^Virus: 0/i;
 
-  $logout = $line;
-  $logout =~ s/%/%%/g;
-  $logout =~ s/\s{20,}/ /g;
-  MailScanner::Log::InfoLog($logout);
+  my $ErrStr = "";
+  $ErrStr = $line if $line =~ /^Panda:ERROR:/;
+  $ErrStr =~ s/^Panda:ERROR:(.+)/$1/ if $ErrStr ne "";
+  chomp($ErrStr) if $ErrStr ne "";
+  MailScanner::Log::InfoLog("Panda WARNING: %s",$ErrStr) if $ErrStr ne "";
+  return 0 if $ErrStr ne "";
 
+  # the wrapper returns the information in the following format
   # EXAMPLE OUTPUT PLEASE? -- nwp 6/5/02
-  # Virus: 2##Base: /var/spool/MailScanner/incoming/24408##1: 'h3MENF6X020229/eicar.com' => EICAR-AV-TEST-FILE##2: 'h3MENF6X020229/eicar.zip' => EICAR-AV-TEST-FILE##
-  # Now you wish you never asked :-)
+  # FOUND: EICAR-AV-TEST-FILE  ##::##eicar_com.zip##::##1DVXmB-0006R4-Fv##::##/var/spool/mailscanner/incoming/24686
+  #          Virus Name                File Name          Message Dir               Base Dir
 
-  $line =~ /Base: (.*?)##/;
-  $BaseDir =~ $1;
-  $numviruses = 0;
   my $temp = $line;
-  while ( $temp =~ /\d+: \'(.*?)\/(.*?)\' => (.*?)##/ )
-  {
-        $id = $1;
+  $numviruses = 0;
+
+  # If the line is a virus report line parse it
+  # Simple
+  while($temp =~ /\t\tFOUND:(.+?)##::##(.+?)##::##(.+?)##::##(.+?)$/){
         $part = $2;
-        $report = $3;
-        $report = $Name . ': ' . $report if $Name;
-        $infections->{$id}{$part} .= "$report\n";
-        $types->{$id}{$part} .= "v"; # it's a real virus
+	    $BaseDir = $4;
+        $id = $3;
+        $report = $1;
+		$report =~ s/^\s+|\s+$|\t|\n//g;
+		$report = $report." found in $part";
+        $report = $Name . ": " . $report if $Name;
+		$report =~ s/\s{2,}/ /g;
+		$part =~ s/^(.+)\-\>(.+)/$2/;
+		MailScanner::Log::InfoLog("%s",$report);
+        $infections->{"$id"}{"$part"} .= "$report\n";
+		#print STDERR "'$part'\n";
+        $types->{"$id"}{"$part"} .= "v";
         $numviruses++;
         $temp = $';
   }
-  #$infected = "$id/$part $report";
+
   return $numviruses;
 
 }
@@ -2328,6 +2373,7 @@ sub ProcessClamAVOutput {
   if (/^Archive:  (.*)$/)
   {
     $clamav_archive = $1;
+    $qmclamav_archive = quotemeta($clamav_archive);
     return 0;
   }
   return 0 if /Empty file\.?$/;
@@ -2338,9 +2384,10 @@ sub ProcessClamAVOutput {
     return 0;
   }
   return 0 if /^  |^Extracting|module failure$/;  # "  inflating", "  deflating.." from --unzip
-  if ($clamav_archive && /^$clamav_archive:/)
+  if ($clamav_archive ne "" && /^$qmclamav_archive:/)
   {
     $clamav_archive = "";
+    $qmclamav_archive = "";
     return 0;
   }
 
@@ -2370,7 +2417,7 @@ sub ProcessClamAVOutput {
   {
      my ($file, $subfile, $virus, $report, $ReportStart);
      $virus = $3;
-     if ($clamav_archive)
+     if ($clamav_archive ne "")
      {
         $file = $clamav_archive;
 	($subfile = $2) =~ s/^.*\///;  # get basename of file
@@ -2483,6 +2530,9 @@ sub ProcessBitdefenderOutput {
   my $logout = $line;
   $logout =~ s/\s{20,}/ /g;
   #print STDERR "virus = \"$virus\"\n";
+  # strip the base from the message dir and remove the ^I junk
+  $logout =~ s/^.+\/\.\///; # New
+  $logout =~ s/\cI/:/g; # New
   MailScanner::Log::InfoLog("%s", $logout);
 
   # Sample output:
