@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: WorkArea.pm,v 1.20.2.5 2005/04/14 19:33:38 jkf Exp $
+#   $Id: WorkArea.pm,v 1.20.2.8 2005/09/15 09:29:28 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -37,11 +37,12 @@ no  strict 'subs'; # Allow bare words for parameter %'s
 
 use DirHandle;
 use File::Path;
+use Cwd 'abs_path';
 
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.20.2.5 $, 10;
+$VERSION = substr q$Revision: 1.20.2.8 $, 10;
 
 #
 # Attributes:
@@ -71,6 +72,11 @@ sub new {
     $destgid = $destgname?getgrnam($destgname):0;
     $this->{gid} = $destgid if $destgid != $currentgid;
     $this->{uid} = $destuid if $destuid != $currentuid;
+  } else {
+    $destuid = 0;
+    $destgid = 0;
+    $this->{gid} = 0;
+    $this->{uid} = 0;
   }
 
   # Create a test file to try with chown
@@ -126,6 +132,13 @@ sub new {
 
   my $parentdir = MailScanner::Config::Value('incomingworkdir');
   MailScanner::Log::DieLog("No Incoming Work Dir defined") unless $parentdir;
+  MailScanner::Log::DieLog("Incoming Work Dir does not exist")
+    unless -d $parentdir;
+  my $realparentdir = abs_path($parentdir);
+  if ($realparentdir ne $parentdir) {
+    MailScanner::Log::WarnLog("Your \"Incoming Work Directory\" should be specified as an absolute path, not including any links. But I will work okay anyway.");
+    $parentdir = $realparentdir;
+  }
 
   my $childdir  = "$parentdir/$$";
 
@@ -230,7 +243,7 @@ sub ClearAll {
     #print STDERR "Studying \"$f\"\n";
     next if $f =~ /^\./;
     # Needs untaint:
-    $f =~ /([-\w]+\.header)$/ and unlink "$1";
+    $f =~ /([-.\w]+\.header)$/ and unlink "$1";
     # And delete core files
     $f =~ /^core$/ and unlink "core";
     # Also needs untaint... sledgehammer. nut.
