@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ZMailer.pm,v 1.1.2.37 2005/03/27 18:21:33 jkf Exp $
+#   $Id: ZMailer.pm,v 1.1.2.38 2005/09/19 18:30:20 jkf Exp $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.37 $, 10;
+$VERSION = substr q$Revision: 1.1.2.38 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -589,7 +589,7 @@ sub AddRecipients {
   my $pos=0;
   #PERT-BBY now, look for first 'to '
   foreach $line (@{$message->{metadata}}) {
-    last if ($line =~ /^to /);
+    last if ($line =~ /^to |^env-end$|^env-eof$/);
     $pos++;
   }
   #PERT-BBY and insert the new ones here
